#!/bin/bash

# === Search for Zytronic Driver Components ===================

# This file is run as a part of the generalized installer
# for the Zytronic Touchscreen Linux Drivers

# It searches for Zytronic components on the disk, and if found returns a 
# non-zero value. If none are found, then zero is returned.

# set to 1 to exit on first violation, with specific exit value
# set to 0 to list all elements, exiting with 0
FAST_EXIT=1
[ ! -z $1 ] && FAST_EXIT=$1 # allow command line override

SRCSO_DIR=/usr/src/modules/zxy100-modules
SRCSU_DIR=/usr/src/modules/zytronic-driver
SRCS1_DIR=/usr/src/modules/zytronic100
SRCS2_DIR=/usr/src/modules/zytronic200
SRCSM_DIR=/usr/src/modules/zytronic_mt
INIT_DIR=/etc/init.d
SBIN_DIR=/usr/sbin
BIN_DIR=/usr/bin
TEMP_TXT=./temp.txt

for dir in $SRCSO_DIR $SRCSU_DIR $SRCS1_DIR $SRCS2_DIR $SRCSM_DIR
do
	if [ -e $dir ]; then
		echo A Zytronic source directory already exists: $dir
		[ $FAST_EXIT -eq 1 ] && exit 1
	fi
done

if [ -e $INIT_DIR/zxy*rebind_init ]; then
	echo There are zxy..rebind_init scripts:
	ls $INIT_DIR/zxy*rebind_init
	[ $FAST_EXIT -eq 1 ] && exit 2
fi

find /etc/rc* -name "*zxy*rebind_init" > $TEMP_TXT
LINES=`cat ./$TEMP_TXT | wc -l`
if [ $LINES -ge 1 ]; then
	echo There are rebind links in the rcX.d dirs
	cat $TEMP_TXT
	[ $FAST_EXIT -eq 1 ] && exit 3
fi
rm -f $TEMP_TXT

if [ -e $SBIN_DIR/zxy*rebind ]; then
	echo The rebind script exists:
	ls $SBIN_DIR/zxy*rebind
	[ $FAST_EXIT -eq 1 ] && exit 4
fi

if [ -e $BIN_DIR/ZyConfig ]; then
	echo ZyConfig exitst:
	ls $BIN_DIR/Zy*
	[ $FAST_EXIT -eq 1 ] && exit 5
fi

exit 0
